@@ -63,12 +63,10 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QString upgradeablePackageId(const PackageKitResource* res) const;
         QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
 
-        void clearPackages(const QStringList &packageNames);
         void resolvePackages(const QStringList &packageNames);
         void fetchDetails(const QString& pkgid) { fetchDetails(QSet<QString>{pkgid}); }
         void fetchDetails(const QSet<QString>& pkgid);
 
-        AbstractResource * resourceForFile(const QUrl & ) override;
         void checkForUpdates() override;
         QString displayName() const override;
 
@@ -100,6 +98,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void includePackagesToAdd();
         void performDetailsFetch();
         AppPackageKitResource* addComponent(const AppStream::Component& component, const QStringList& pkgNames);
+        void updateProxy();
 
         QScopedPointer<AppStream::Pool> m_appdata;
         PackageKitUpdater* m_updater;
