@@ -28,6 +28,12 @@
 #include <QJsonArray>
 #include <QDebug>
 
+#if defined(WITH_MARKDOWN)
+extern "C" {
+#include <mkdio.h>
+}
+#endif
+
 const QStringList PackageKitResource::m_objects({ QStringLiteral("qrc:/qml/DependenciesButton.qml") });
 
 PackageKitResource::PackageKitResource(QString packageName, QString summary, PackageKitBackend* parent)
@@ -148,11 +154,14 @@ AbstractResource::State PackageKitResource::state()
 
 void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const QString &packageId, bool arch)
 {
+    auto oldState = state();
     if (arch)
         m_packages[info].append(packageId);
     else
         m_packages[info].prepend(packageId);
-    emit stateChanged();
+
+    if (oldState != state())
+        emit stateChanged();
 }
 
 QStringList PackageKitResource::categories()
@@ -160,9 +169,9 @@ QStringList PackageKitResource::categories()
     return { QStringLiteral("Unknown") };
 }
 
-bool PackageKitResource::isTechnical() const
+AbstractResource::Type PackageKitResource::type() const
 {
-    return true;
+    return Technical;
 }
 
 void PackageKitResource::fetchDetails()
@@ -175,9 +184,9 @@ void PackageKitResource::fetchDetails()
     backend()->fetchDetails(pkgid);
 }
 
-void PackageKitResource::failedFetchingDetails(PackageKit::Transaction::Error, const QString& msg)
+void PackageKitResource::failedFetchingDetails(PackageKit::Transaction::Error error, const QString& msg)
 {
-    qWarning() << "error fetching details" << msg;
+    qWarning() << "error fetching details" << error << msg;
 }
 
 void PackageKitResource::setDependenciesCount(int deps)
@@ -204,10 +213,14 @@ void PackageKitResource::setDetails(const PackageKit::Details & details)
 }
 
 void PackageKitResource::fetchChangelog()
+{
+}
+
+void PackageKitResource::fetchUpdateDetails()
 {
     const auto pkgid = availablePackageId();
     if (pkgid.isEmpty()) {
-        connect(this, &PackageKitResource::stateChanged, this, &PackageKitResource::fetchChangelog);
+        connect(this, &PackageKitResource::stateChanged, this, &PackageKitResource::fetchUpdateDetails);
         return;
     }
     PackageKit::Transaction* t = PackageKit::Daemon::getUpdateDetail(availablePackageId());
@@ -244,15 +257,33 @@ static QStringList urlToLinks(const QStringList& urls)
 }
 
 void PackageKitResource::updateDetail(const QString& packageID, const QStringList& updates, const QStringList& obsoletes, const QStringList& vendorUrls,
-                                      const QStringList& /*bugzillaUrls*/, const QStringList& /*cveUrls*/, PackageKit::Transaction::Restart restart, const QString& updateText,
+                                      const QStringList& /*bugzillaUrls*/, const QStringList& /*cveUrls*/, PackageKit::Transaction::Restart restart, const QString &_updateText,
                                       const QString& /*changelog*/, PackageKit::Transaction::UpdateState state, const QDateTime& /*issued*/, const QDateTime& /*updated*/)
 {
+#if defined(WITH_MARKDOWN)
+    const char* xx = _updateText.toUtf8().constData();
+    MMIOT *markdownHandle = mkd_string(xx, _updateText.size(), 0);
+
+    QString updateText;
+    if ( !mkd_compile( markdownHandle, MKD_FENCEDCODE | MKD_GITHUBTAGS | MKD_AUTOLINK ) ) {
+        updateText = _updateText;
+    } else {
+        char *htmlDocument;
+        const int size = mkd_document( markdownHandle, &htmlDocument );
+
+        updateText = QString::fromUtf8( htmlDocument, size );
+    }
+    mkd_cleanup( markdownHandle );
+
+#else
+    const auto& updateText = _updateText;
+#endif
+
     const auto name = PackageKit::Daemon::packageName(packageID);
 
     QString info;
-    addIfNotEmpty(i18n("Current Version:"), joinPackages(updates, {}, name), info);
     addIfNotEmpty(i18n("Obsoletes:"), joinPackages(obsoletes, {}, name), info);
-    addIfNotEmpty(i18n("New Version:"), updateText, info);
+    addIfNotEmpty(i18n("Release Notes:"), updateText, info);
     addIfNotEmpty(i18n("Update State:"), PackageKitMessages::updateStateMessage(state), info);
     addIfNotEmpty(i18n("Restart:"), PackageKitMessages::restartMessage(restart), info);
 
