@@ -25,6 +25,7 @@
 #include <resources/AbstractResourcesBackend.h>
 #include <QVariantList>
 #include <Snapd/Client>
+#include <functional>
 
 class QAction;
 class SnapReviewsBackend;
@@ -37,7 +38,7 @@ public:
     explicit SnapBackend(QObject* parent = nullptr);
 
     ResultsStream * search(const AbstractResourcesBackend::Filters & search) override;
-    ResultsStream * findResourceByPackageName(const QUrl& search) override;
+    ResultsStream * findResourceByPackageName(const QUrl& search);
 
     QString displayName() const override;
     int updatesCount() const override;
@@ -56,8 +57,12 @@ public:
 
 private:
     void setFetching(bool fetching);
+
     template <class T>
-    ResultsStream* populate(T* snaps, AbstractResource::State state);
+    ResultsStream* populateWithFilter(T* snaps, std::function<bool(const QSharedPointer<QSnapdSnap>&)>& filter);
+
+    template <class T>
+    ResultsStream* populate(T* snaps);
 
     QHash<QString, SnapResource*> m_resources;
     StandardBackendUpdater* m_updater;
