@@ -44,8 +44,11 @@ DiscoverNotifier::DiscoverNotifier(QObject * parent)
                 m_needsReboot = true;
                 showRebootNotification();
                 Q_EMIT updatesChanged();
+                Q_EMIT needsRebootChanged(true);
             }
         });
+
+        connect(module, &BackendNotifierModule::foundUpgradeAction, this, &DiscoverNotifier::foundUpgradeAction);
     }
     connect(&m_timer, &QTimer::timeout, this, &DiscoverNotifier::showUpdatesNotification);
     m_timer.setSingleShot(true);
@@ -76,7 +79,7 @@ void DiscoverNotifier::showDiscoverUpdates()
 void DiscoverNotifier::showUpdatesNotification()
 {
     if (state()==NoUpdates) {
-        //it's not very helpful to notify that everyting is in order
+        //it's not very helpful to notify that everything is in order
         return;
     }
 
@@ -197,16 +200,39 @@ QStringList DiscoverNotifier::loadedModules() const
 
 void DiscoverNotifier::showRebootNotification()
 {
-    KNotification *notification = new KNotification(QLatin1String("notification"), KNotification::Persistent | KNotification::DefaultEvent);
+    KNotification *notification = new KNotification(QStringLiteral("notification"), KNotification::Persistent | KNotification::DefaultEvent);
     notification->setIconName(QStringLiteral("system-software-update"));
     notification->setActions(QStringList{QLatin1String("Restart")});
     notification->setTitle(i18n("Restart is required"));
     notification->setText(i18n("The system needs to be restarted for the updates to take effect."));
 
-    connect(notification, &KNotification::action1Activated, this, [] () {
-        QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
-        interface.asyncCall(QStringLiteral("logout"), 0, 1, 2); // Options: do not ask again | reboot | force
+    connect(notification, &KNotification::action1Activated, this, &DiscoverNotifier::reboot);
+
+    notification->sendEvent();
+}
+
+void DiscoverNotifier::reboot()
+{
+    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
+    interface.asyncCall(QStringLiteral("logout"), 0, 1, 2); // Options: do not ask again | reboot | force
+}
+
+void DiscoverNotifier::foundUpgradeAction(UpgradeAction* action)
+{
+    KNotification *notification = new KNotification(QStringLiteral("distupgrade-notification"), KNotification::Persistent | KNotification::DefaultEvent);
+    notification->setIconName(QStringLiteral("system-software-update"));
+    notification->setActions(QStringList{QLatin1String("Upgrade")});
+    notification->setTitle(i18n("Upgrade available"));
+    notification->setText(i18n("New version: %1", action->description()));
+
+    connect(notification, &KNotification::action1Activated, this, [action] () {
+        action->trigger();
     });
 
     notification->sendEvent();
 }
+
+bool DiscoverNotifier::isSystemUpToDate() const
+{
+    return m_count==0 && m_securityCount==0;
+}
